<?php

namespace Drupal\liveness\Plugin\Block;

use Drupal\Core\Block\BlockBase;
use Drupal\Core\Cache\Cache;

/**
 * Provides a 'LivenessBlock' block.
 *
 * @Block(
 *   id = "liveness_block",
 *   admin_label = @Translation("Liveness Block"),
 * )
 */
class LivenessBlock extends BlockBase {

  /**
   * {@inheritdoc}
   */
  public function build() {
    $config = \Drupal::config('liveness.settings');
    if (!$config->get('enable_liveness_block')) {
      return [];
    }

    $log_file = DRUPAL_ROOT . '/sites/default/files/liveness_log.txt';
    if (!file_exists($log_file)) {
      return [];
    }

    $events = array_reverse(file($log_file));
    $recent_events = [];
    $now = time();
    $display_timeframe = $config->get('display_events_timeframe') ?? 48; // Default to 48 hours

    foreach ($events as $event) {
      preg_match('/(\d{4}-\d{2}-\d{2} \d{2}:\d{2}:\d{2}) - (.*)/', $event, $matches);
      if (!empty($matches)) {
        $timestamp = strtotime($matches[1]);
        if ($now - $timestamp <= $display_timeframe * 3600) { // Convert hours to seconds
          $recent_events[] = $event;
          if (count($recent_events) >= 3) {
            break;
          }
        }
      }
    }

    if (empty($recent_events)) {
      return [];
    }

    return [
      '#theme' => 'liveness_block',
      '#events' => $recent_events,
      '#cache' => [
        'max-age' => 90, // Cache for maximum 90 seconds.
      ],
    ];
  }
}

